@@ -1,7 +1,7 @@
 #ifndef ELEKTRA_KDB_IO_HPP
 #define ELEKTRA_KDB_IO_HPP
 
-/**
+/*
  * @brief See examples/cpp_example_userio.cpp for how to use
  * USER_DEFINED_IO
  */
@@ -17,13 +17,13 @@ namespace kdb
 
 inline std::ostream & printError(std::ostream & os, kdb::Key const & error)
 {
-	if (!error.getMeta<const kdb::Key>("error"))
-	{
-		// no error available
-		return os;
-	}
+	try {
+		if (!error.getMeta<const kdb::Key>("error"))
+		{
+			// no error available
+			return os;
+		}
 
-	try{
 		error.getMeta<std::string>("error");
 		os << "Error (#" << error.getMeta<std::string>("error/number") << ") occurred!" << std::endl;
 		os << "Description: " << error.getMeta<std::string>("error/description") << std::endl;
@@ -31,7 +31,7 @@ inline std::ostream & printError(std::ostream & os, kdb::Key const & error)
 		os << "Module: " << error.getMeta<std::string>("error/module") << std::endl;
 		os << "At: " << error.getMeta<std::string>("error/file") << ":" << error.getMeta<std::string>("error/line") << std::endl;
 		os << "Reason: " << error.getMeta<std::string>("error/reason") << std::endl;
-	} catch (kdb::KeyMetaException const& e)
+	} catch (kdb::KeyTypeConversion const& e)
 	{
 		os << "Error meta data is not set correctly by a plugin: " << e.what() << std::endl;
 	}
@@ -41,13 +41,13 @@ inline std::ostream & printError(std::ostream & os, kdb::Key const & error)
 
 inline std::ostream & printWarnings(std::ostream & os, kdb::Key const & error)
 {
-	if (!error.getMeta<const kdb::Key>("warnings"))
-	{
-		// no warnings were issued
-		return os;
-	}
+	try {
+		if (!error.getMeta<const kdb::Key>("warnings"))
+		{
+			// no warnings were issued
+			return os;
+		}
 
-	try{
 		int nr = error.getMeta<int>("warnings");
 		if (!nr)
 		{
@@ -68,11 +68,11 @@ inline std::ostream & printWarnings(std::ostream & os, kdb::Key const & error)
 			os << "\tIngroup: " << error.getMeta<std::string>(name.str() + "/ingroup") << std::endl;
 			os << "\tModule: " << error.getMeta<std::string>(name.str() + "/module") << std::endl;
 			os << "\tAt: " << error.getMeta<std::string>(name.str() + "/file") << ":"
-				  << error.getMeta<std::string>(name.str() + "/line") << std::endl;
+				<< error.getMeta<std::string>(name.str() + "/line") << std::endl;
 			os << "\tReason: " << error.getMeta<std::string>(name.str() + "/reason") << std::endl;
 		}
 
-	} catch (kdb::KeyMetaException const& e)
+	} catch (kdb::KeyTypeConversion const& e)
 	{
 		os << "Warnings meta data not set correctly by a plugin: " << e.what() << std::endl;
 	}
