@@ -58,6 +58,10 @@ void test_ksdup()
 	succeed_if (ks3.size() == 3, "size not correct");
 
 	KeySet ks4 (ks3.dup());
+	succeed_if (ks4.lookup("user/key3/1"), "could not find key");
+	succeed_if (ks4.lookup("user/key3/2"), "could not find key");
+	succeed_if (ks4.lookup("user/key3/3"), "could not find key");
+	succeed_if (ks4.lookup("user/key3/3").getString() == "value", "value not correct");
 	succeed_if (ks4.size() == 3, "size not correct");
 
 	// ks3.toStream(stdout, 0);
@@ -122,7 +126,7 @@ void test_iterate()
 	succeed_if (!null, "null key");
 
 	ks3.rewind();
-	for (size_t i=0; i<ks3.size(); i++)
+	for (ssize_t i=0; i<ks3.size(); i++)
 	{
 		Key k = ks3.next();
 		char str[] = "user/key3/X";
@@ -189,7 +193,7 @@ void test_cursor()
 	cursor_t cursorTest = ks3.getCursor();
 
 	ks3.rewind();
-	for (size_t i=0; i<ks3.size(); i++)
+	for (ssize_t i=0; i<ks3.size(); i++)
 	{
 		Key k = ks3.next();
 		if (i==0) cursorTest = ks3.getCursor();
@@ -309,7 +313,7 @@ void test_append()
 	ks5.append(v[2]=Key("user/s/3", KEY_END));
 
 	ks5.rewind();
-	for (size_t i=0; i<ks5.size(); ++i)
+	for (ssize_t i=0; i<ks5.size(); ++i)
 	{
 		succeed_if (*ks5.next() == *v[i], "wrong order");
 	}
@@ -336,7 +340,7 @@ void test_per()
 		ks.append(permutation[1]);
 		ks.append(permutation[2]);
 		ks.rewind();
-		for (size_t i=0; i<ks.size(); ++i)
+		for (ssize_t i=0; i<ks.size(); ++i)
 		{
 			succeed_if (*ks.next() == *solution[i], "wrong order");
 		}
@@ -353,7 +357,7 @@ void test_per()
 		ks.append(permutation[2]);
 		ks.append(permutation[3]);
 		ks.rewind();
-		for (size_t i=0; i<ks.size(); ++i)
+		for (ssize_t i=0; i<ks.size(); ++i)
 		{
 			succeed_if (*ks.next() == *solution[i], "wrong order");
 		}
@@ -371,7 +375,7 @@ void test_per()
 		ks.append(permutation[3]);
 		ks.append(permutation[4]);
 		ks.rewind();
-		for (size_t i=0; i<ks.size(); ++i)
+		for (ssize_t i=0; i<ks.size(); ++i)
 		{
 			// note: raw pointers check the identity! It needs to be the same reference
 			succeed_if (*ks.next() == *solution[i], "wrong order");
@@ -391,7 +395,7 @@ void test_per()
 		ks.append(permutation[4]);
 		ks.append(permutation[5]);
 		ks.rewind();
-		for (size_t i=0; i<ks.size(); ++i)
+		for (ssize_t i=0; i<ks.size(); ++i)
 		{
 			succeed_if (*ks.next() == *solution[i], "wrong order");
 		}
@@ -410,7 +414,7 @@ void test_appendowner()
 	ks.append(v[2]=Key("user/s/1", KEY_OWNER, "max", KEY_END));
 
 	ks.rewind();
-	for (size_t i=0; i<ks.size(); ++i)
+	for (ssize_t i=0; i<ks.size(); ++i)
 	{
 		succeed_if (*ks.next() == *v[i], "wrong order");
 	}
@@ -433,7 +437,7 @@ void test_perowner()
 		ks.append(permutation[1]);
 		ks.append(permutation[2]);
 		ks.rewind();
-		for (size_t i=0; i<ks.size(); ++i)
+		for (ssize_t i=0; i<ks.size(); ++i)
 		{
 			succeed_if(*ks.next() == *solution[i], "wrong order");
 		}
@@ -450,7 +454,7 @@ void test_perowner()
 		ks.append(permutation[2]);
 		ks.append(permutation[3]);
 		ks.rewind();
-		for (size_t i=0; i<ks.size(); ++i)
+		for (ssize_t i=0; i<ks.size(); ++i)
 		{
 			succeed_if (*ks.next() == *solution[i], "wrong order");
 		}
@@ -468,7 +472,7 @@ void test_perowner()
 		ks.append(permutation[3]);
 		ks.append(permutation[4]);
 		ks.rewind();
-		for (size_t i=0; i<ks.size(); ++i)
+		for (ssize_t i=0; i<ks.size(); ++i)
 		{
 			succeed_if (*ks.next() == *solution[i], "wrong order");
 		}
@@ -487,7 +491,7 @@ void test_perowner()
 		ks.append(permutation[4]);
 		ks.append(permutation[5]);
 		ks.rewind();
-		for (size_t i=0; i<ks.size(); ++i)
+		for (ssize_t i=0; i<ks.size(); ++i)
 		{
 			succeed_if (*ks.next() == *solution[i], "wrong order");
 		}
@@ -683,7 +687,7 @@ void rcall(KeySet ks)
 	succeed_if (ks.lookup("user/xxx"), "could not find key");
 	succeed_if (!ks.lookup("user/yyy"), "could not find key");
 
-	// dont destroy ks
+	// don't destroy ks
 	ks.release();
 }
 
@@ -755,7 +759,7 @@ void test_lookuppop()
 		*Key ("user/key3/3", KEY_VALUE, "value", KEY_END),
 		KS_END);
 
-	for (size_t i=ks4.size(); i>0; i--)
+	for (ssize_t i=ks4.size(); i>0; i--)
 	{
 		char str[] = "user/key3/X";
 
@@ -774,7 +778,7 @@ void test_lookuppop()
 		*Key ("user/key3/3", KEY_VALUE, "value", KEY_END),
 		KS_END);
 
-	for (size_t i=ks5.size(); i>0; i--)
+	for (ssize_t i=ks5.size(); i>0; i--)
 	{
 		char str[] = "user/key3/X";
 
@@ -790,6 +794,33 @@ void test_lookuppop()
 	}
 }
 
+void test_duplicate()
+{
+	cout << "testing ksdup" << endl;
+
+	KeySet ks3 (5,
+		*Key ("user/key3/1", KEY_END),
+		*Key ("user/key3/2", KEY_END),
+		*Key ("user/key3/3", KEY_VALUE, "value", KEY_END),
+		KS_END);
+	succeed_if (ks3.lookup("user/key3/1"), "could not find key");
+	succeed_if (ks3.lookup("user/key3/2"), "could not find key");
+	succeed_if (ks3.lookup("user/key3/3"), "could not find key");
+	succeed_if (ks3.lookup("user/key3/3").getString() == "value", "value not correct");
+	succeed_if (ks3.size() == 3, "size not correct");
+
+	KeySet ks4;
+	ks4 = ks3;
+	succeed_if (ks4.lookup("user/key3/1"), "could not find key");
+	succeed_if (ks4.lookup("user/key3/2"), "could not find key");
+	succeed_if (ks4.lookup("user/key3/3"), "could not find key");
+	succeed_if (ks4.lookup("user/key3/3").getString() == "value", "value not correct");
+	succeed_if (ks4.size() == 3, "size not correct");
+
+	// ks3.toStream(stdout, 0);
+	// ks4.toStream(stdout, 0);
+}
+
 
 int main()
 {
@@ -812,6 +843,7 @@ int main()
 	test_ksccall();
 	test_ksrelease();
 	test_lookuppop();
+	test_duplicate();
 
 	cout << endl;
 	cout << "test_key RESULTS: " << nbTest << " test(s) done. " << nbError << " error(s)." << endl;
