@@ -10,23 +10,24 @@ void test_basic()
 	cout << "testing metainfo" << endl;
 	Key test;
 
-	try {
-		test.getMeta<mode_t>("mode");
-		succeed_if (0, "missing mode should raise exception");
-	} catch (KeyNoSuchMeta const &e) {
-		succeed_if (1, "exception raised successfully");
-	}
+	succeed_if (test.hasMeta("mode") == false, "has meta?");
+	succeed_if (test.getMeta<mode_t>("mode") == 0, "not properly default constructed");
 
 	test.setMeta<mode_t>("mode", 0775);
+	succeed_if (test.hasMeta("mode") == true, "has not meta even though set?");
 
-	//note that mode is not octal!
 	succeed_if (test.getMeta<mode_t>("mode") == 0775, "not correct default mode for dir");
 
 	test.setMeta<int>("myint", 333);
 	succeed_if (test.getMeta<int>("myint") == 333, "could not set other meta");
 
 	test.setMeta<double>("mydouble", 333.3);
-	succeed_if (test.getMeta<double>("mydouble") == 333.3, "could not set other meta");
+	succeed_if (test.hasMeta("mydouble"), "no meta data even though it was just set");
+	succeed_if (test.getMeta<double>("mydouble") >= 333.2, "could not set other meta");
+	succeed_if (test.getMeta<double>("mydouble") <= 333.4, "could not set other meta");
+
+	test.delMeta("mydouble");
+	succeed_if (!test.hasMeta("mydouble"), "meta data there even though it was just deleted");
 
 	test.setMeta<std::string>("mystr", "str");
 	succeed_if (test.getMeta<std::string>("mystr") == "str", "could not set other meta");
@@ -50,18 +51,16 @@ void test_basic()
 	const char * nstr = test.getMeta<const char*>("not available");
 	succeed_if (nstr == 0, "did not get null pointer on not available meta data");
 
-	try {
-		test.getMeta<int>("not available");
-		succeed_if (0, "exception did not raise");
-	} catch (KeyNoSuchMeta const& e)
-	{
-		succeed_if (1, "no such meta data");
-	}
+	succeed_if (test.getMeta<int>("not available") == 0, "not default constructed");
+	succeed_if (test.getMeta<std::string>("not available") == "", "not default constructed");
+
+	test.setMeta<std::string>("wrong", "not an int");
 
 	try {
-		test.getMeta<std::string>("not available");
+		succeed_if (test.hasMeta("wrong") == true, "meta is here");
+		test.getMeta<int>("wrong");
 		succeed_if (0, "exception did not raise");
-	} catch (KeyNoSuchMeta const& e)
+	} catch (KeyTypeConversion const& e)
 	{
 		succeed_if (1, "no such meta data");
 	}
@@ -84,12 +83,6 @@ void test_iter()
 	Key end = static_cast<ckdb::Key*>(0); // key = 0
 	succeed_if (!end, "key is a null key");
 
-	k.rewindMeta();
-	while (meta = k.nextMeta())
-	{
-		// cout << meta.getName() << " " << meta.getString() << endl;
-	}
-
 	int count = 0;
 	k.rewindMeta();
 	while (meta = k.nextMeta()) count ++;
@@ -127,13 +120,6 @@ void test_copy()
 	k.setMeta<int>("a", 420);
 
 	succeed_if (k.getMeta<int>("a") == 420, "could not get value set before");
-	try {
-		c.getMeta<int>("a");
-		succeed_if (0, "exception did not raise");
-	} catch (KeyBadMeta const& e)
-	{
-		succeed_if (1, "no such meta data");
-	}
 
 	c.copyMeta(k, "a");
 	succeed_if (c.getMeta<int>("a") == 420, "could not get value copied before");
@@ -154,19 +140,19 @@ void test_copy()
 	}
 
 	succeed_if (d.getMeta<std::string>("a") == "420", "did not copy meta value in the loop");
-	succeed_if (k.getMeta<const ckdb::Key*>("a") == d.getMeta<const ckdb::Key*>("a"),
+	succeed_if (d.getMeta<const ckdb::Key*>("a") == d.getMeta<const ckdb::Key*>("a"),
 			"copy meta did not work in the loop");
 
 	succeed_if (d.getMeta<std::string>("") == "meta value", "did not copy meta value in the loop");
-	succeed_if (k.getMeta<const ckdb::Key*>("") == d.getMeta<const ckdb::Key*>(""),
+	succeed_if (d.getMeta<const ckdb::Key*>("") == d.getMeta<const ckdb::Key*>(""),
 			"copy meta did not work in the loop");
 
 	succeed_if (d.getMeta<std::string>("b") == "b meta value", "did not copy meta value in the loop");
-	succeed_if (k.getMeta<const ckdb::Key*>("b") == d.getMeta<const ckdb::Key*>("b"),
+	succeed_if (d.getMeta<const ckdb::Key*>("b") == d.getMeta<const ckdb::Key*>("b"),
 			"copy meta did not work in the loop");
 
 	succeed_if (d.getMeta<std::string>("c") == "c meta value", "did not copy meta value in the loop");
-	succeed_if (k.getMeta<const ckdb::Key*>("c") == d.getMeta<const ckdb::Key*>("c"),
+	succeed_if (d.getMeta<const ckdb::Key*>("c") == d.getMeta<const ckdb::Key*>("c"),
 			"copy meta did not work in the loop");
 }
 
@@ -186,17 +172,53 @@ void test_string()
 	succeed_if (m, "could not get meta key");
 	succeed_if (m.getString()  == "a meta value", "could not get meta string");
 
-	try
-	{
-		Key m1 = k.getMeta<const Key> ("x");
-		succeed_if (!m1, "could not get meta key");
-		succeed_if (m1.getKey() == 0, "key should be 0");
-		succeed_if (m1.getString()  == "", "could not get meta string");
-	}
-	catch (...)
-	{}
+	Key m1 = k.getMeta<const Key> ("x");
+	succeed_if (!m1, "got not existing meta key");
 }
 
+void test_copyAll()
+{
+	cout << "testing copy all meta" << std::endl;
+
+	Key k ("user/metakey",
+			KEY_META, "", "meta value",
+			KEY_META, "a", "a meta value",
+			KEY_META, "b", "b meta value",
+			KEY_META, "c", "c meta value",
+			KEY_META, "i", "420",
+			KEY_END);
+	Key c;
+
+	c.copyAllMeta(k);
+
+	succeed_if (c.getMeta<const ckdb::Key*>("a") == c.getMeta<const ckdb::Key*>("a"), "copy meta did not work");
+	succeed_if (c.getMeta<const ckdb::Key*>("") == c.getMeta<const ckdb::Key*>(""), "copy meta did not work");
+	succeed_if (c.getMeta<int>("i") == 420, "could not get value copied before");
+	succeed_if (c.getMeta<std::string>("i") == "420", "did not copy meta value in the loop");
+	succeed_if (c.getMeta<const ckdb::Key*>("a") == c.getMeta<const ckdb::Key*>("a"), "copy meta did not work");
+
+	Key d;
+
+	d.copyAllMeta(k);
+	succeed_if (d.getMeta<std::string>("i") == "420", "did not copy meta value in the loop");
+	succeed_if (d.getMeta<int>("i") == 420, "could not get value copied before");
+	succeed_if (k.getMeta<const ckdb::Key*>("a") == d.getMeta<const ckdb::Key*>("a"),
+			"copy meta did not work in the loop");
+
+	succeed_if (d.getMeta<std::string>("") == "meta value", "did not copy meta value in the loop");
+	succeed_if (k.getMeta<const ckdb::Key*>("") == d.getMeta<const ckdb::Key*>(""),
+			"copy meta did not work in the loop");
+
+	succeed_if (d.getMeta<std::string>("b") == "b meta value", "did not copy meta value in the loop");
+	succeed_if (k.getMeta<const ckdb::Key*>("b") == d.getMeta<const ckdb::Key*>("b"),
+			"copy meta did not work in the loop");
+
+	succeed_if (d.getMeta<std::string>("c") == "c meta value", "did not copy meta value in the loop");
+	succeed_if (k.getMeta<const ckdb::Key*>("c") == d.getMeta<const ckdb::Key*>("c"),
+			"copy meta did not work in the loop");
+}
+
+
 int main()
 {
 	cout << "KEY META TESTS" << endl;
@@ -206,6 +228,7 @@ int main()
 	test_iter();
 	test_copy();
 	test_string();
+	test_copyAll();
 
 	cout << endl;
 	cout << "testcpp_meta RESULTS: " << nbTest << " test(s) done. " << nbError << " error(s)." << endl;
