@@ -111,7 +111,7 @@
  * These libraries for backends will be loaded and with it the
  * @p KDB datastructure will be initialized.
  *
- * You must always call this method before retrieving or commiting any
+ * You must always call this method before retrieving or committing any
  * keys to the database. In the end of the program,
  * after using the key database, you must not forget to kdbClose().
  * You can use the atexit () handler for it.
@@ -187,6 +187,11 @@ KDB * kdbOpen(Key *errorKey)
 		ELEKTRA_ADD_WARNING(17, errorKey,
 				"kdbGet() of " KDB_KEY_MOUNTPOINTS
 				" failed");
+		elektraBackendClose(handle->defaultBackend, errorKey);
+		elektraSplitDel(handle->split);
+		handle->defaultBackend = 0;
+		handle->trie = 0;
+
 		keySetName(errorKey, keyName(initialParent));
 		keyDel(initialParent);
 		return handle;
@@ -271,6 +276,7 @@ int kdbClose(KDB *handle, Key *errorKey)
 	elektraTrieClose(handle->trie, errorKey);
 
 	elektraBackendClose (handle->defaultBackend, errorKey);
+	handle->defaultBackend = 0;
 
 	if (handle->modules)
 	{
@@ -481,7 +487,7 @@ int kdbGet(KDB *handle, KeySet *ks, Key *parentKey)
 	// Check if a update is needed at all
 	switch(elektraGetCheckUpdateNeeded(split, parentKey))
 	{
-	case 0: // We dont need an update so lets do nothing
+	case 0: // We don't need an update so let's do nothing
 		keySetName (parentKey, keyName(initialParent));
 		keyDel (initialParent);
 		elektraSplitDel (split);
