@@ -12,7 +12,7 @@
 
 #include "ccode.h"
 
-#include <tests.h>
+#include <tests_internal.h>
 
 CCodeData *get_data()
 {
@@ -89,7 +89,7 @@ void check_reversibility(const char* msg)
 	elektraCcodeEncode (encode, d);
 
 	elektraCcodeDecode (encode, d);
-	succeed_if (compare_key(encode, decode) == 0, "was not reversible");
+	compare_key(encode, decode);
 
 	free (d);
 	keyDel (decode);
