@@ -48,7 +48,7 @@ int elektraDbusGet(Plugin *handle ELEKTRA_UNUSED,
 		keyNew ("system/elektra/modules/dbus/infos/description",
 			KEY_VALUE, "Prints timestamps when a method is called", KEY_END),
 		keyNew ("system/elektra/modules/dbus/infos/provides",
-			KEY_VALUE, "dbus", KEY_END),
+			KEY_VALUE, "notification", KEY_END),
 		keyNew ("system/elektra/modules/dbus/infos/placements",
 			KEY_VALUE, "postcommit", KEY_END),
 		keyNew ("system/elektra/modules/dbus/infos/needs",
