@@ -27,19 +27,20 @@
 
 #include <tests_plugin.h>
 
+
 void test_readfstab()
 {
-	Key * parentKey = keyNew ("user/tests/fstab", KEY_VALUE, srcdir_file("fstab"), KEY_END);
+	Key * parentKey = keyNew ("user/tests/fstab", KEY_VALUE, srcdir_file("fstab/fstab"), KEY_END);
 	KeySet *conf = 0;
 	PLUGIN_OPEN("fstab");
 
 	KeySet *ks=ksNew(0);
 
-	printf ("%s\n", srcdir_file("fstab"));
+	printf ("Using file: %s\n", srcdir_file("fstab/fstab"));
 
 	succeed_if (plugin->kdbGet(plugin, ks, parentKey) >= 1, "call to kdbGet was not successful");
 
-	output_keyset(ks);
+	// output_keyset(ks);
 
 	Key *key = ksLookupByName(ks, "user/tests/fstab/mediaext4/device",0);
 	exit_if_fail (key, "rootfs device not found");
@@ -48,7 +49,8 @@ void test_readfstab()
 	exit_if_fail (key = ksLookupByName(ks, "user/tests/fstab/mediaext4/dumpfreq",0), "rootfs device not found");
 	succeed_if (strcmp( "0", keyValue(key)) == 0, "dumpfreq not correct");
 
-	ksDel (ks);
+	ksDel(ks);
+	keyDel(parentKey);
 
 	PLUGIN_CLOSE();
 }
