@@ -561,10 +561,8 @@ Ni_PUBLIC int Ni_WriteStream(Ni_node restrict n, FILE * restrict stream,
          break;
 
       if(fprintf(stream, ";Ni1\n"
-                         "; Generated by Nickel v%d.%d.%d (see chaoslizard.org/devel/bohr).\n\n",
-                         (Ni_HEADER_VERSION >> 24) & 0xff,
-                         (Ni_HEADER_VERSION >> 16) & 0xff,
-                         (Ni_HEADER_VERSION >>  8) & 0xff) < 0)
+                          "; Generated by Nickel Plugin using Elektra (see libelektra.org).\n\n"
+        ) < 0)
       {
          break;
       }
