@@ -107,7 +107,7 @@ BEGIN_TEST(tree)
    Ni_Free(node);
 END_TEST()
 
-BEGIN_TEST(values)
+BEGIN_TEST(test_values)
    Ni_node node = Ni_New();
    assert(node != NULL);
 
@@ -210,9 +210,8 @@ BEGIN_TEST(parse_spaces_quotes)
 END_TEST()
 
 BEGIN_TEST(output)
-   //FIXME: this won't be correct depending on what version of Nickel's in use
    char desired[] = {";Ni1\n"
-                     "; Generated by Nickel v1.1.0 (see chaoslizard.org/devel/bohr).\n\n"
+                     "; Generated by Nickel Plugin using Elektra (see libelektra.org).\n\n"
                      "1 = 1's value\n\n"
                      "[1]\n\n"
                      " [[2]]\n"
@@ -263,7 +262,7 @@ END_TEST()
 BEGIN_TEST(output_modified)
    //FIXME: this won't be correct depending on what version of Nickel's in use
    char desired[] = {";Ni1\n"
-                     "; Generated by Nickel v1.1.0 (see chaoslizard.org/devel/bohr).\n\n"
+                     "; Generated by Nickel Plugin using Elektra (see libelektra.org).\n\n"
                      "3 = 3's value\n"
                     };
 
@@ -447,7 +446,7 @@ int main()
 	TEST(ver);
 	TEST(new);
 	TEST(tree);
-	TEST(values);
+	TEST(test_values);
 	TEST(parse_spaces_quotes);
 	TEST(output);
 	TEST(output_modified);
