@@ -26,6 +26,8 @@
 
 #include "resolver.h"
 
+#include "kdbos.h"
+
 #include <stdlib.h>
 
 #ifdef HAVE_CTYPE_H
@@ -66,6 +68,14 @@ void resolverInit (resolverHandle *p, const char *path)
 	p->path = path;
 }
 
+static resolverHandle * elektraGetResolverHandle(Plugin *handle, Key *parentKey)
+{
+	resolverHandles *pks = elektraPluginGetData(handle);
+	if (!strncmp(keyName(parentKey), "user", 4)) return &pks->user;
+	else return &pks->system;
+}
+
+
 void resolverClose (resolverHandle *p)
 {
 	free (p->filename); p->filename = 0;
@@ -176,10 +186,7 @@ int elektraResolverClose(Plugin *handle, Key *errorKey ELEKTRA_UNUSED)
 
 int elektraResolverGet(Plugin *handle, KeySet *returned, Key *parentKey)
 {
-	resolverHandles *pks = elektraPluginGetData(handle);
-	resolverHandle *pk = 0;
-	if (!strncmp(keyName(parentKey), "user", 4)) pk = &pks->user;
-	else pk = &pks->system;
+	resolverHandle *pk = elektraGetResolverHandle(handle, parentKey);
 
 	// might be useless, will not harm
 	keySetString(parentKey, pk->filename);
@@ -502,10 +509,7 @@ int elektraSetCommit(resolverHandle *pk, Key *parentKey)
 
 int elektraResolverSet(Plugin *handle, KeySet *returned ELEKTRA_UNUSED, Key *parentKey)
 {
-	resolverHandles *pks = elektraPluginGetData(handle);
-	resolverHandle *pk = 0;
-	if (!strncmp(keyName(parentKey), "user", 4)) pk = &pks->user;
-	else pk = &pks->system;
+	resolverHandle *pk = elektraGetResolverHandle(handle, parentKey);
 
 	// might be useless, will not harm
 	keySetString(parentKey, pk->tempfile);
@@ -543,7 +547,7 @@ int elektraResolverSet(Plugin *handle, KeySet *returned ELEKTRA_UNUSED, Key *par
 int elektraResolverError(Plugin *handle, KeySet *returned ELEKTRA_UNUSED, Key *parentKey)
 {
 	int errnoSave = errno;
-	resolverHandle *pk = elektraPluginGetData(handle);
+	resolverHandle *pk = elektraGetResolverHandle(handle, parentKey);
 
 	if (unlink (pk->tempfile) == -1)
 	{
@@ -562,42 +566,6 @@ int elektraResolverError(Plugin *handle, KeySet *returned ELEKTRA_UNUSED, Key *p
 	return 0;
 }
 
-/**
- * @return 1 on success (Relative path)
- * @returns 0 on success (Absolute path)
- * @return -1 on a non-valid file
- */
-int elektraResolverCheckFile(const char* filename)
-{
-	if(!filename) return -1;
-	if(filename[0] == '0') return -1;
-
-	size_t size = strlen(filename);
-	char *buffer = malloc(size + sizeof ("system/"));
-	strcpy(buffer, "system/");
-	strcat(buffer, filename);
-
-	/* Because of the outbreak bugs these tests are not enough */
-	Key *check = keyNew(buffer, KEY_END);
-	if(!strcmp(keyName(check), "")) goto error;
-	if(!strcmp(keyName(check), "system")) goto error;
-	keyDel(check);
-	free(buffer);
-
-	/* Be strict, dont allow any .., even if it would be allowed sometimes */
-	if(strstr (filename, "..") != 0) return -1;
-
-
-	if(filename[0] == '/') return 0;
-
-	return 1;
-
-error:
-	keyDel (check);
-	free (buffer);
-	return -1;
-}
-
 
 Plugin *ELEKTRA_PLUGIN_EXPORT(resolver)
 {
