@@ -37,6 +37,9 @@
 // 4.7.2 supports %ms but yields warning using -Wformat together with
 // -ansi -pedantic
 // warning: ISO C does not support the 'm' scanf flag
+#define GCC_VERSION (__GNUC__ * 10000 \
+                              + __GNUC_MINOR__ * 100 \
+                              + __GNUC_PATCHLEVEL__)
 #if  GCC_VERSION < 40800
 # pragma GCC diagnostic ignored "-Wformat"
 #endif
