@@ -66,6 +66,9 @@ int elektraSuccessGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *pare
 			keyNew ("system/elektra/modules/success/exports/set",
 				KEY_FUNC, elektraSuccessSet,
 				KEY_END),
+			keyNew ("system/elektra/modules/success/exports/error",
+				KEY_FUNC, elektraSuccessError,
+				KEY_END),
 			keyNew ("system/elektra/modules/success/exports/checkfile",
 				KEY_FUNC, elektraSuccessCheckFile,
 				KEY_END),
