@@ -102,7 +102,7 @@ static int elektraYajlParseNumber(void *ctx, const char *stringVal,
 #endif
 
 	keySetString(current, stringVal);
-	keySetMeta(current, "type", "number");
+	keySetMeta(current, "type", "double");
 
 	// restore old character in buffer
 	stringValue[stringLen] = delim;
@@ -277,13 +277,37 @@ static void elektraYajlParseSuppressEmpty(KeySet *returned, Key* parentKey)
 	}
 }
 
+static inline KeySet *elektraGetModuleConfig()
+{
+	return ksNew (30,
+	keyNew ("system/elektra/modules/yajl",
+		KEY_VALUE, "yajl plugin waits for your orders", KEY_END),
+	keyNew ("system/elektra/modules/yajl/exports", KEY_END),
+	keyNew ("system/elektra/modules/yajl/exports/get",
+		KEY_FUNC, elektraYajlGet,
+		KEY_END),
+	keyNew ("system/elektra/modules/yajl/exports/set",
+		KEY_FUNC, elektraYajlSet,
+		KEY_END),
+#include "readme_yajl.c"
+	keyNew ("system/elektra/modules/yajl/infos/version",
+		KEY_VALUE, PLUGINVERSION, KEY_END),
+	keyNew ("system/elektra/modules/yajl/config", KEY_END),
+	keyNew ("system/elektra/modules/yajl/config/",
+		KEY_VALUE, "system",
+		KEY_END),
+	keyNew ("system/elektra/modules/yajl/config/below",
+		KEY_VALUE, "user",
+		KEY_END),
+	KS_END);
+}
+
 int elektraYajlGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned,
 		Key *parentKey)
 {
 	if (!strcmp (keyName(parentKey), "system/elektra/modules/yajl"))
 	{
-		KeySet *moduleConfig =
-#include "contract.h"
+		KeySet *moduleConfig = elektraGetModuleConfig();
 		ksAppend(returned, moduleConfig);
 		ksDel(moduleConfig);
 		return 1;
