@@ -9,13 +9,18 @@ check_version
 ROOT=$USER_ROOT
 FILE=`mktemp`
 PLUGIN=$PLUGIN
-DATADIR=@CMAKE_CURRENT_BINARY_DIR@/data
 
 cleanup()
 {
 	rm -f $FILE
 }
 
+[ -e /dev/stdout ]
+exit_if_fail "For export/import /dev (and /proc) must be mounted"
+
+[ -e /proc/self/fd/0 ]
+exit_if_fail "For export/import /proc (and /dev) must be mounted"
+
 for PLUGIN in $PLUGINS
 do
 	if is_not_rw_storage
