@@ -24,6 +24,8 @@ do
 		MOUNT_PLUGIN="tcl ccode null"
 		;;
 	"yajl")
+		MOUNT_PLUGIN="$PLUGIN"
+		#TODO: add plugin to fix problem
 		DO_NOT_TEST_ROOT_VALUE="yes"
 		;;
 	"simpleini")
@@ -110,7 +112,7 @@ do
 		[ $? != "0" ]
 		succeed_if "got removed key $ROOT"
 
-		check_set_get_rm $ROOT/value other_value
+		check_set_rm $ROOT/value other_value
 
 		echo "testing array"
 
