@@ -10,32 +10,25 @@ gid_t nbGid;
 
 char file [KDB_MAX_PATH_LENGTH];
 char srcdir [KDB_MAX_PATH_LENGTH];
+char tmpfilename [KDB_MAX_PATH_LENGTH];
 
 #ifdef HAVE_CLEARENV
 int clearenv();
 #endif
 
+char *tempHome;
+int tempHomeLen;
+
+static void clean_temp_home (void);
+
 /**Does some useful startup.
  */
 int init (int argc, char**argv)
 {
+	char *tmpvar;
+
 	setlocale (LC_ALL, "");
 
-	nbUid = getuid();
-	nbGid = getgid();
-
-	if (getenv ("srcdir"))
-	{
-		strncpy (srcdir, getenv ("srcdir"), sizeof(srcdir));
-	} else {
-		if (argc > 1)
-		{
-			strncpy (srcdir, argv[1], sizeof(srcdir));
-		} else {
-			strcpy (srcdir, ".");
-			warn_if_fail (0, "srcdir not set, will try current directory");
-		}
-	}
 #ifdef HAVE_CLEARENV
 	clearenv();
 #else
@@ -43,7 +36,32 @@ int init (int argc, char**argv)
 	unsetenv("USER");
 #endif
 
-	setenv("HOME","/tmp/elektra-test",1);
+	nbUid = getuid();
+	nbGid = getgid();
+
+	if (argc > 1)
+	{
+		strncpy (srcdir, argv[1], sizeof(srcdir));
+	} else {
+		strncpy (srcdir, BUILTIN_DATA_FOLDER, sizeof(srcdir));
+	}
+
+	tmpvar = getenv ("TMPDIR");
+	if (!tmpvar)
+	{
+		tmpvar = "/tmp";
+	}
+	tempHomeLen = strlen (tmpvar) + 1 + 13 + 6 + 1;
+	tempHome = malloc (tempHomeLen);
+	succeed_if (tempHome != 0, "malloc failed");
+	snprintf (tempHome, tempHomeLen, "%s/elektra-test.XXXXXX", tmpvar);
+	succeed_if (mkdtemp (tempHome) != 0, "mkdtemp failed");
+	setenv("HOME",tempHome,1);
+
+	atexit (clean_temp_home);
+
+	succeed_if(tmpfilename == tmpnam(tmpfilename),
+			"could not generate file name");
 
 	return 0;
 }
@@ -183,6 +201,16 @@ char * srcdir_file(const char * fileName)
 	return file;
 }
 
+const char *elektraFilename()
+{
+	return tmpfilename;
+}
+
+void elektraUnlink(const char* filename)
+{
+	unlink(filename);
+}
+
 void clear_sync (KeySet *ks)
 {
 	Key *k;
@@ -324,23 +352,23 @@ int output_warnings(Key *warningKey)
 		buffer[10] = i/10%10 + '0';
 		buffer[11] = i%10 + '0';
 		printf ("buffer is: %s\n", buffer);
-		strncat(buffer, "/number" , sizeof(buffer));
+		strncat(buffer, "/number" , sizeof(buffer) -1);
 		printf ("number: %s\n", keyString(keyGetMeta(warningKey, buffer)));
-		buffer[12] = '\0'; strncat(buffer, "/description" , sizeof(buffer));
+		buffer[12] = '\0'; strncat(buffer, "/description" , sizeof(buffer) -1);
 		printf ("description: %s\n", keyString(keyGetMeta(warningKey, buffer)));
-		buffer[12] = '\0'; strncat(buffer, "/ingroup" , sizeof(buffer));
+		buffer[12] = '\0'; strncat(buffer, "/ingroup" , sizeof(buffer) -1);
 		keyGetMeta(warningKey, buffer);
 		printf ("ingroup: %s\n", keyString(keyGetMeta(warningKey, buffer)));
-		buffer[12] = '\0'; strncat(buffer, "/module" , sizeof(buffer));
+		buffer[12] = '\0'; strncat(buffer, "/module" , sizeof(buffer) -1);
 		keyGetMeta(warningKey, buffer);
 		printf ("module: %s\n", keyString(keyGetMeta(warningKey, buffer)));
-		buffer[12] = '\0'; strncat(buffer, "/file" , sizeof(buffer));
+		buffer[12] = '\0'; strncat(buffer, "/file" , sizeof(buffer) -1);
 		keyGetMeta(warningKey, buffer);
 		printf ("file: %s\n", keyString(keyGetMeta(warningKey, buffer)));
-		buffer[12] = '\0'; strncat(buffer, "/line" , sizeof(buffer));
+		buffer[12] = '\0'; strncat(buffer, "/line" , sizeof(buffer) -1);
 		keyGetMeta(warningKey, buffer);
 		printf ("line: %s\n", keyString(keyGetMeta(warningKey, buffer)));
-		buffer[12] = '\0'; strncat(buffer, "/reason" , sizeof(buffer));
+		buffer[12] = '\0'; strncat(buffer, "/reason" , sizeof(buffer) -1);
 		keyGetMeta(warningKey, buffer);
 		printf ("reason: %s\n", keyString(keyGetMeta(warningKey, buffer)));
 	}
@@ -372,3 +400,13 @@ int output_error(Key *errorKey)
 
 	return 0;
 }
+
+static void clean_temp_home (void)
+{
+	if (!tempHome) return;
+
+	rmdir (tempHome);
+	free (tempHome);
+	tempHome = NULL;
+	tempHomeLen = 0;
+}
