@@ -51,6 +51,9 @@ extern int nbTest;
 extern uid_t nbUid;
 extern gid_t nbGid;
 
+extern char *tempHome;
+extern int tempHomeLen;
+
 int init(int argc, char** argv);
 
 #define warn_if_fail(expression, message) \
@@ -103,6 +106,7 @@ int init(int argc, char** argv);
 
 #define compare_key_name(k1, k2) \
 { \
+	nbTest++; \
 	if (strcmp(keyName(k1), keyName(k2))) \
 	{ \
 		char errorMsg [BUFFER_LENGTH]; \
@@ -118,6 +122,7 @@ int init(int argc, char** argv);
 
 #define succeed_if_same_string(s1, s2) \
 { \
+	nbTest++; \
 	if (strcmp(s1, s2)) \
 	{ \
 		char errorMsg [BUFFER_LENGTH]; \
@@ -151,7 +156,7 @@ int init(int argc, char** argv);
 		keyRewindMeta(k2); \
 		while ((meta = keyNextMeta (k1)) != 0) \
 		{ \
-			const Key const * metaCmp = keyNextMeta(k2); \
+			const Key *const metaCmp = keyNextMeta(k2); \
 			if (metaCmp == 0) \
 			{ \
 				nbError++; \
@@ -167,7 +172,7 @@ int init(int argc, char** argv);
 			check_attributes(attributes); \
 		} \
 	 \
-		const Key const * metaCmp = keyNextMeta(k2); \
+		const Key *const metaCmp = keyNextMeta(k2); \
 		if (metaCmp != 0) \
 		{ \
 			nbError++; \
@@ -228,6 +233,8 @@ int compare_files (const char * filename);
 int compare_line_files (const char *filename, const char *genfilename);
 
 char *srcdir_file(const char * fileName);
+const char *elektraFilename();
+void elektraUnlink(const char* filename);
 
 Key * create_root_key (const char *backendName);
 KeySet *create_conf (const char *filename);
